#!/usr/bin/env python
from OpenSSL import crypto
import gzip,sys,pdb

_END_DELIM = "-----END CERTIFICATE-----"
def verify(blob, signature, certs_file):
    """Verifies a message against a signature.

      Args:
        blob: string,The message to verify.
        signature: string,The signature that is used for the verification.
        certs_file: certificate from which we will extract the Public Key

      Returns:
        True if message was signed by the private key associated with the public
        key that this object was constructed with.
        else returns False
    """
    with open(certs_file, 'r') as cert_data:
        certs = [cert + _END_DELIM for cert in cert_data.read().split(_END_DELIM) if cert.strip('\t\n\r')]
        for cert in certs:
            cert_obj = crypto.load_certificate(crypto.FILETYPE_PEM, cert)
            try:
                crypto.verify(cert_obj, signature, blob, 'sha256')
                return True
            except crypto.Error as er:
                return False

print('************************************************************')
print('Usage: ./verify_attest.py <partition.cert> <attestation.dat>')
print('************************************************************')
print('')
attest_data = open(sys.argv.pop(), 'rb').read()
certs_file = sys.argv.pop()
blob, signature = attest_data[:-256], attest_data[-256:]
verified = verify(blob, signature, certs_file)
print('Signature verified!:signature verification passed' if verified else 'Signature failed!')